<?php
/**
 * Blogarama functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Blogarama
 */

if ( ! function_exists( 'blogarama_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function blogarama_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Blogarama, use a find and replace
	 * to change 'blogarama' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'blogarama', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_editor_style();
	add_theme_support( 'custom-header' );
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'blogarama-small-thumbnail',  100, 100, true );
	add_image_size( 'blogarama-featured-thumbnail',  800, 567, true );
	add_image_size( 'blogarama-featured--page-thumbnail',  1140, 800, true );
	add_image_size( 'blogarama-widget-post-thumb',  64, 64, true );
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 400,
		'flex-height' => true,
		'flex-width'  => true,
		'header-text' => array( 'site-title', 'site-description' ),
	) );
	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'blogarama' ),
		'secondary' => __('Top Menu', 'blogarama')
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'blogarama_custom_background_args', array(
		'default-color' => 'f7f7f7',
		'default-image' => '',
	) ) );
	$args = array(
	'width'         => 1170,
	'height'        => 200,
	);
	add_theme_support( 'custom-header', $args );
}
endif;
add_action( 'after_setup_theme', 'blogarama_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function blogarama_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'blogarama_content_width', 640 );
}
add_action( 'after_setup_theme', 'blogarama_content_width', 0 );
/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function blogarama_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'blogarama' ),
		'id'            => 'blogarama-sidebar-1',
		'description'   => __( 'Main Sidebar', 'blogarama' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Footer One', 'blogarama' ),
		'id' => 'blogarama-footer-one-widget',
		'description'   => __( 'Footer first column widget', 'blogarama' ),
		'before_widget' => '<div id="footer-one" class="widget footer-widget">',
		'after_widget' => "</div>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Footer Two', 'blogarama' ),
		'id' => 'blogarama-footer-two-widget',
		'description'   => __( 'Footer second column widget', 'blogarama' ),
		'before_widget' => '<div id="footer-two" class="widget footer-widget">',
		'after_widget' => "</div>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Footer Three', 'blogarama' ),
		'id' => 'blogarama-footer-three-widget',
		'description'   => __( 'Footer third column widget', 'blogarama' ),
		'before_widget' => '<div id="footer-three" class="widget footer-widget">',
		'after_widget' => "</div>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
}
add_action( 'widgets_init', 'blogarama_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function blogarama_scripts() {
	
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() .'/assets/css/bootstrap.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() .'/assets/font-awesome/css/font-awesome.min.css' );
	wp_enqueue_style('blogarama-google-fonts', '//fonts.googleapis.com/css?family=Lato:400,300,700,900|Merriweather:400,700,300,500|Raleway:300,400,700|Lora:300,400,700');
	wp_enqueue_style( 'blogarama-ie', get_stylesheet_directory_uri() . "/assets/css/ie.css", array()  );
	wp_style_add_data( 'blogarama-ie', 'conditional', 'IE' );
	wp_enqueue_style( 'blogarama-style', get_stylesheet_uri() );
	
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') );
	wp_enqueue_script( 'blogarama-custom-js', get_template_directory_uri() . '/js/custom.js', array('jquery-masonry', 'imagesloaded') );
	wp_enqueue_script( 'blogarama-ie-responsive-js', get_template_directory_uri() . '/js/ie-responsive.min.js', array() );
	wp_script_add_data( 'blogarama-ie-responsive-js', 'conditional', 'lt IE 9' );
	wp_enqueue_script( 'blogarama-ie-shiv', get_template_directory_uri() . "/js/html5shiv.min.js");
	wp_script_add_data( 'blogarama-ie-shiv', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'blogarama-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	wp_enqueue_script( 'blogarama-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'blogarama_scripts' );


if(! is_user_logged_in()){
	add_filter( 'comment_form_defaults', 'blogarama_remove_textarea' );
}
function blogarama_remove_textarea($defaults)
{
    $defaults['comment_field'] = '';
    return $defaults;
}
add_filter( 'comment_form_default_fields', 'blogarama_comment_fields', 10 );
function blogarama_comment_fields( $fields ) {
 
	// get the current commenter if available
	$commenter = wp_get_current_commenter();
 
	// core functionality
	$req      = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );
	$html_req = ( $req ? " required='required'" : '' );
 
	// Change just the author field
	$fields = array(
	'comment_notes_after' => ' ',
	'comment_field' => '<p class="comment-form-comment"><textarea id="comment" name="comment" aria-required="true" placeholder="'.__( 'Your Message...', 'blogarama' ).'" rows="8" cols="37" wrap="hard"></textarea></p>',
	  
	'author' =>
		  '<div class="row"><div class="col-md-4"><p class="comment-form-author">' .
		  '<input id="author" placeholder="'. __('Your name *...', 'blogarama') .'" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
		  '" size="30"' . $aria_req . ' />' . ( $req ? '<span style="color:red" class="required"></span>' : '' ) . '</p></div>',

	'email' =>
		  '<div class="col-md-4"><p class="comment-form-email">' .
		  '<input id="email" placeholder="'. __('Your email *...', 'blogarama') .'" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .
		  '" size="30"' . $aria_req . ' />' . ( $req ? '<span style="color:red" class="required"></span>' : '' ) . '</p></div>',

	'url' =>
		  '<div class="col-md-4"><p class="comment-form-url">' .
		  '<input id="url" placeholder="'. __('Your website...', 'blogarama') .'" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) .
		  '" size="30" /></p></div></div>'
	  
	  
	);
	return $fields;
 
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';


/**
 * Implement the Custom Widget.
 */
require get_template_directory() . '/inc/widget.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
