<?php
/**
 * Blogarama Theme Customizer.
 *
 * @package Blogarama
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function blogarama_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	
	$categories = get_categories();
	$cats = array();
	$i = 0;
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cats[$category->slug] = $category->name;
	}
	$wp_customize->add_panel( 'blogarama_home_featured_panel', array(
		'priority'       => 10,
		'capability'     => 'edit_theme_options',
		'title'          => __('Home Page Features', 'blogarama' ),
		'description'    => __('Section that will show on Home page', 'blogarama' ),
	) );
	
	//Featured Page
	$wp_customize->add_section( 'blogarama_featured' , array(
		'title'      => __( 'Featured Page', 'blogarama' ),
		'priority'   => 20,
		'panel'  => 'blogarama_home_featured_panel',
	) );
	
	$wp_customize->add_setting('blogarama_featured_setting', array(
		'default'        => 0,
		'sanitize_callback' => 'blogarama_sanitize_checkbox',
	));

	$wp_customize->add_control('blogarama_featured_control', array(
		'settings' => 'blogarama_featured_setting',
		'label'    => __('Display Featured Page', 'blogarama'),
		'section'  => 'blogarama_featured',
		'type'     => 'checkbox',
		'priority'	=> 24
	));
	
	$wp_customize->add_setting('blogarama_featured_link_setting', array(
		'default'        => 0,
		'sanitize_callback' => 'blogarama_sanitize_checkbox',
	));

	$wp_customize->add_control('blogarama_featured_link_setting', array(
		'settings' => 'blogarama_featured_link_setting',
		'label'    => __('Add Page link', 'blogarama'),
		'section'  => 'blogarama_featured',
		'active_callback' =>'blogarama_featured_active_callback',
		'type'     => 'checkbox',
		'priority'	=> 24
	));
	
	$wp_customize->add_setting( 'blogarama_featured_page', array(
		'default'        => 0,
		'sanitize_callback' => 'absint'
	) );

	$wp_customize->add_control( 'blogarama_featured_page', array(
		'label'    => __( 'Select Featured Page', 'blogarama' ),
		'section'  => 'blogarama_featured',
		'active_callback' =>'blogarama_featured_active_callback',
		'type'     => 'dropdown-pages',
		'priority'	=> 24
	) );
	
	/* social media option */
	$wp_customize->add_section( 'blogarama_social_section' , array(
		'title'       => __( 'Social Media Icons', 'blogarama' ),
		'priority'    => 25,
		'description' => __( 'Optional social media buttons in the header', 'blogarama' ),
	) );

	$wp_customize->add_setting( 'blogarama_facebook_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_facebook', array(
		'label'    => __( 'Enter your Facebook url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_facebook_setting',
		'priority'    => 1,
	) ) );

	$wp_customize->add_setting( 'blogarama_twitter_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_twitter', array(
		'label'    => __( 'Enter your Twitter url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_twitter_setting',
		'priority'    => 2,
	) ) );
	
	$wp_customize->add_setting( 'blogarama_google_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_google', array(
		'label'    => __( 'Enter your Google+ url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_google_setting',
		'priority'    => 3,
	) ) );

	$wp_customize->add_setting( 'blogarama_pinterest_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_pinterest', array(
		'label'    => __( 'Enter your Pinterest url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_pinterest_setting',
		'priority'    => 4,
	) ) );

	$wp_customize->add_setting( 'blogarama_linkedin_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_linkedin', array(
		'label'    => __( 'Enter your Linkedin url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_linkedin_setting',
		'priority'    => 5,
	) ) );

	$wp_customize->add_setting( 'blogarama_youtube_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_youtube', array(
		'label'    => __( 'Enter your Youtube url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_youtube_setting',
		'priority'    => 6,
	) ) );

	$wp_customize->add_setting( 'blogarama_tumblr_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_tumblr', array(
		'label'    => __( 'Enter your Tumblr url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_tumblr_setting',
		'priority'    => 7,
	) ) );

	$wp_customize->add_setting( 'blogarama_instagram_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_instagram', array(
		'label'    => __( 'Enter your Instagram url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_instagram_setting',
		'priority'    => 8,
	) ) );

	$wp_customize->add_setting( 'blogarama_flickr_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_flickr', array(
		'label'    => __( 'Enter your Flickr url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_flickr_setting',
		'priority'    => 9,
	) ) );

	$wp_customize->add_setting( 'blogarama_vimeo_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_vimeo', array(
		'label'    => __( 'Enter your Vimeo url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_vimeo_setting',
		'priority'    => 1,
	) ) );
	$wp_customize->add_setting( 'blogarama_rss_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_rss', array(
		'label'    => __( 'Enter your RSS url', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_rss_setting',
		'priority'    => 11,
	) ) );

	$wp_customize->add_setting( 'blogarama_email_setting', array (			
		'sanitize_callback' => 'sanitize_email',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blogarama_email', array(
		'label'    => __( 'Enter your email address', 'blogarama' ),
		'section'  => 'blogarama_social_section',
		'settings' => 'blogarama_email_setting',
		'priority'    => 12,
	) ) );
	
	/* color option */
	$wp_customize->add_setting( 'blogarama_primary_color_setting', array (
		'default'     => '#2aabc5',
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blogarama_primary_color', array(
		'label'    => __( 'Theme Primary Color', 'blogarama' ),
		'section'  => 'colors',
		'settings' => 'blogarama_primary_color_setting',
	) ) );
	
	$wp_customize->add_setting( 'blogarama_secondary_color_setting', array (
		'default'     => '#00e1f5',
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blogarama_secondary_color', array(
		'label'    => __( 'Theme Secondary Color', 'blogarama' ),
		'section'  => 'colors',
		'settings' => 'blogarama_secondary_color_setting',
	) ) );
}
add_action( 'customize_register', 'blogarama_customize_register' );
	
function blogarama_featured_active_callback() {
	if ( get_theme_mod( 'blogarama_featured_setting', 0 ) ) {
		return true;
	}
	return false;
}


/**
 * Sanitize checkbox
 */

if (!function_exists( 'blogarama_sanitize_checkbox' ) ) :
	function blogarama_sanitize_checkbox( $input ) {
		if ( $input != 1 ) {
			return 0;
		} else {
			return 1;
		}
	}
endif;

/**
 * Sanitize integer input
 */
if ( ! function_exists( 'blogarama_sanitize_integer' ) ) :
	function blogarama_sanitize_integer( $input ) {		
		return absint($input);
	}
endif;

if ( ! function_exists( 'blogarama_sanitize_category' ) ){
	function blogarama_sanitize_category( $input ) {
		$categories = get_categories();
		$cats = array();
		$i = 0;
		foreach($categories as $category){
			if($i==0){
				$default = $category->slug;
				$i++;
			}
			$cats[$category->slug] = $category->name;
		}
		$valid = $cats;

		if ( array_key_exists( $input, $valid ) ) {
			return $input;
		} else {
			return '';

		}
	}
}

function blogarama_sanitize_text_field( $str ) {

	return esc_html(sanitize_text_field( $str ));

}
		
if ( ! function_exists( 'blogarama_apply_color' ) ) :
  function blogarama_apply_color() {
	?>
	<style id="color-settings">
	<?php if (esc_html(get_theme_mod('blogarama_primary_color_setting')) ) { ?>
		.site-title a:hover, .main-navigation, .footer-widget-container ul li a:hover, .blogarama-recent-post .meta-info-comment a:hover, .blogarama-recent-post .post-author a:hover, .widget-area ul li a:hover, a, #featured-post h3 a:hover,
.featured-articles .article-excerpt h2 a:hover, .entry-title a:hover, .site-footer a:hover, .slide-post-details h1 a:hover, .comment-meta .fn a, .reply a, .nav-previous a, .nav-next a{color:<?php echo esc_html(get_theme_mod('blogarama_primary_color_setting')); ?>}
		.navigation-wrap, .social-meidia li,.main-navigation .current_page_item > a, .main-navigation .current-menu-item > a, .main-navigation .current_page_ancestor > a, .main-navigation .current-menu-ancestor > a, .main-navigation a:hover, button, input[type="button"], input[type="reset"], input[type="submit"], .footer-widget-container thead, .footer-widget .tagcloud a, .featured-post-meta, .read_more, .next.page-numbers, .prev.page-numbers, .main-navigation ul ul, .rr-left:before{ background:<?php echo esc_html(get_theme_mod('blogarama_primary_color_setting')); ?>}
		.widget-title, .footer-widget-container { border-color:<?php echo esc_html(get_theme_mod('blogarama_primary_color_setting')); ?> !important}
		.widget_tag_cloud a{background:<?php echo esc_html(get_theme_mod('blogarama_primary_color_setting')); ?>}
	<?php } ?>
	
	<?php if (esc_html(get_theme_mod('blogarama_secondary_color_setting')) ) { ?>
		.main-navigation a:hover, .main-navigation a.focus, .main-navigation .current_page_item > a, .main-navigation .current-menu-item > a, .main-navigation .current_page_item > a,
.main-navigation .current-menu-item > a, .main-navigation .current_page_ancestor > a, .main-navigation .current-menu-ancestor > a, #search-icon .fa-search:hover  {color:<?php echo esc_html(get_theme_mod('blogarama_secondary_color_setting')); ?>}
		.rr-left:after{ background:<?php echo esc_html(get_theme_mod('blogarama_secondary_color_setting')); ?>}
	<?php } ?>
	
	</style>
	<?php	  
  }
endif;
add_action( 'wp_head', 'blogarama_apply_color' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function blogarama_customize_preview_js() {
	wp_enqueue_script( 'blogarama_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'blogarama_customize_preview_js' );
